BlocksClient

Struct BlocksClient 

pub struct BlocksClient<T, Client> { /* private fields */ }
A client for working with blocks.

Implementations

Source

impl<T, Client> BlocksClient<T, Client>

pub fn new(client: Client) -> Self

Create a new BlocksClient.

Source

impl<T, Client> BlocksClient<T, Client>
where T: Config, Client: OnlineClientT<T>,

pub fn at( &self, block_hash: T::Hash, ) -> impl Future<Output = Result<Block<T, Client>, Error>> + Send + 'static

Obtain block details given the provided block hash.

Warning

This call only supports blocks produced since the most recent runtime upgrade. You can attempt to retrieve older blocks, but may run into errors attempting to work with them.

pub fn at_latest( &self, ) -> impl Future<Output = Result<Block<T, Client>, Error>> + Send + 'static

Obtain block details of the latest block hash.

pub fn subscribe_all( &self, ) -> impl Future<Output = Result<Pin<Box<dyn Stream<Item = Result<Block<T, Client>, Error>> + Send>>, Error>> + Send + 'static
where Client: Send + Sync + 'static,

Subscribe to all new blocks imported by the node.

Note: You probably want to use Self::subscribe_finalized() most of the time.

pub fn subscribe_best( &self, ) -> impl Future<Output = Result<Pin<Box<dyn Stream<Item = Result<Block<T, Client>, Error>> + Send>>, Error>> + Send + 'static
where Client: Send + Sync + 'static,

Subscribe to all new blocks imported by the node onto the current best fork.

Note: You probably want to use Self::subscribe_finalized() most of the time.

pub fn subscribe_finalized( &self, ) -> impl Future<Output = Result<Pin<Box<dyn Stream<Item = Result<Block<T, Client>, Error>> + Send>>, Error>> + Send + 'static
where Client: Send + Sync + 'static,

Subscribe to finalized blocks.