pub struct ConstantsClient<T, Client> { /* private fields */ }Expand description
A client for accessing constants.
Implementations
Sourceimpl<T, Client> ConstantsClient<T, Client>
impl<T, Client> ConstantsClient<T, Client>
Sourcepub fn new(client: Client) -> Self
pub fn new(client: Client) -> Self
Create a new ConstantsClient.
Sourceimpl<T: Config, Client: OfflineClientT<T>> ConstantsClient<T, Client>
impl<T: Config, Client: OfflineClientT<T>> ConstantsClient<T, Client>
Sourcepub fn validate<Address: ConstantAddress>(
&self,
address: &Address,
) -> Result<(), Error>
pub fn validate<Address: ConstantAddress>( &self, address: &Address, ) -> Result<(), Error>
Run the validation logic against some constant address you’d like to access. Returns Ok(())
if the address is valid (or if it’s not possible to check since the address has no validation hash).
Return an error if the address was not valid or something went wrong trying to validate it (ie
the pallet or constant in question do not exist at all).
Sourcepub fn at<Address: ConstantAddress>(
&self,
address: &Address,
) -> Result<Address::Target, Error>
pub fn at<Address: ConstantAddress>( &self, address: &Address, ) -> Result<Address::Target, Error>
Access the constant at the address given, returning the type defined by this address. This is probably used with addresses given from static codegen, although you can manually construct your own, too.