pub type DynamicAddress = Address<DecodedValueThunk>;Expand description
The type of address typically used to return dynamic constant values.
Aliased Type
pub struct DynamicAddress { /* private fields */ }pub type DynamicAddress = Address<DecodedValueThunk>;The type of address typically used to return dynamic constant values.
pub struct DynamicAddress { /* private fields */ }