Module error

Module error 

Types representing the errors that can be returned.

Re-exports

pub use crate::metadata::Metadata;

Structs

DecodeError
An error produced while attempting to decode some type.
EncodeError
An error produced while attempting to encode some type.
ModuleError
Details about a module error that has occurred.
RawModuleError
The error details about a module error that has occurred.

Enums

ArithmeticError
An error relating to arithmetic when dispatching a transaction.
BlockError
Block error
DispatchError
An error dispatching a transaction.
Error
The underlying error enum, generic over the type held by the Runtime variant. Prefer to use the Error<E> and Error aliases over using this type directly.
MetadataError
Something went wrong trying to access details in the metadata.
MetadataTryFromError
An error emitted if something goes wrong converting frame_metadata types into crate::Metadata.
RpcError
An RPC error. Since we are generic over the RPC client that is used, the error is boxed and could be casted.
StorageAddressError
Something went wrong trying to encode a storage address.
TokenError
An error relating to tokens when dispatching a transaction.
TransactionError
Transaction error.
TransactionalError
An error relating to thr transactional layers when dispatching a transaction.