Module runtime_api

Module runtime_api 

Types associated with executing runtime API calls.

Structs

Payload
A runtime API payload containing the generic argument data and interpreting the result of the call as ReturnTy.
RuntimeApi
Execute runtime API calls.
RuntimeApiClient
Execute runtime API calls.

Traits

RuntimeApiPayload
This represents a runtime API payload that can call into the runtime of node.

Functions

dynamic
Create a new DynamicRuntimeApiPayload.

Type Aliases

DynamicRuntimeApiPayload
A dynamic runtime API payload.