Payload

Struct Payload 

pub struct Payload<ArgsData, ReturnTy> { /* private fields */ }
A runtime API payload containing the generic argument data and interpreting the result of the call as ReturnTy.

This can be created from static values (ie those generated via the subxt macro) or dynamic values via dynamic.

Implementations

Source

impl<ReturnTy, ArgsData> Payload<ArgsData, ReturnTy>

pub fn new( trait_name: impl Into<String>, method_name: impl Into<String>, args_data: ArgsData, ) -> Self

Create a new Payload.

pub fn unvalidated(self) -> Self

Do not validate this call prior to submitting it.

pub fn trait_name(&self) -> &str

Returns the trait name.

pub fn method_name(&self) -> &str

Returns the method name.

pub fn args_data(&self) -> &ArgsData

Returns the arguments data.