pub struct Address<StorageKey, ReturnTy, Fetchable, Defaultable, Iterable> { /* private fields */ }Expand description
A concrete storage address. This can be created from static values (ie those generated
via the subxt macro) or dynamic values via dynamic and dynamic_root.
Implementations
Sourceimpl<StorageKey, ReturnTy, Fetchable, Defaultable, Iterable> Address<StorageKey, ReturnTy, Fetchable, Defaultable, Iterable>where
StorageKey: EncodeWithMetadata,
ReturnTy: DecodeWithMetadata,
impl<StorageKey, ReturnTy, Fetchable, Defaultable, Iterable> Address<StorageKey, ReturnTy, Fetchable, Defaultable, Iterable>where
StorageKey: EncodeWithMetadata,
ReturnTy: DecodeWithMetadata,
Sourcepub fn new(
pallet_name: impl Into<String>,
entry_name: impl Into<String>,
storage_entry_keys: Vec<StorageKey>,
) -> Self
pub fn new( pallet_name: impl Into<String>, entry_name: impl Into<String>, storage_entry_keys: Vec<StorageKey>, ) -> Self
Create a new Address to use to access a storage entry.
Sourcepub fn unvalidated(self) -> Self
pub fn unvalidated(self) -> Self
Do not validate this storage entry prior to accessing it.
Sourcepub fn to_root_bytes(&self) -> Vec<u8> ⓘ
pub fn to_root_bytes(&self) -> Vec<u8> ⓘ
Return bytes representing the root of this storage entry (ie a hash of
the pallet and entry name). Use crate::storage::StorageClient::address_bytes()
to obtain the bytes representing the entire address.