StorageClient

Struct StorageClient 

pub struct StorageClient<T, Client> { /* private fields */ }
Query the runtime storage.

Implementations

Source

impl<T, Client> StorageClient<T, Client>

pub fn new(client: Client) -> Self

Create a new StorageClient

Source

impl<T, Client> StorageClient<T, Client>
where T: Config, Client: OfflineClientT<T>,

pub fn validate<Address: StorageAddress>( &self, address: &Address, ) -> Result<(), Error>

Run the validation logic against some storage address you’d like to access. Returns Ok(()) if the address is valid (or if it’s not possible to check since the address has no validation hash). Return an error if the address was not valid or something went wrong trying to validate it (ie the pallet or storage entry in question do not exist at all).

pub fn address_root_bytes<Address: StorageAddress>( &self, address: &Address, ) -> Vec<u8>

Convert some storage address into the raw bytes that would be submitted to the node in order to retrieve the entries at the root of the associated address.

pub fn address_bytes<Address: StorageAddress>( &self, address: &Address, ) -> Result<Vec<u8>, Error>

Convert some storage address into the raw bytes that would be submitted to the node in order to retrieve an entry. This fails if StorageAddress::append_entry_bytes does; in the built-in implementation this would be if the pallet and storage entry being asked for is not available on the node you’re communicating with, or if the metadata is missing some type information (which should not happen).

Source

impl<T, Client> StorageClient<T, Client>
where T: Config, Client: OnlineClientT<T>,

pub fn at(&self, block_hash: T::Hash) -> Storage<T, Client>

Obtain storage at some block hash.

pub fn at_latest( &self, ) -> impl Future<Output = Result<Storage<T, Client>, Error>> + Send + 'static

Obtain storage at the latest block hash.