pub struct StorageClient<T, Client> { /* private fields */ }Expand description
Query the runtime storage.
Implementations
Sourceimpl<T, Client> StorageClient<T, Client>
impl<T, Client> StorageClient<T, Client>
Sourcepub fn new(client: Client) -> Self
pub fn new(client: Client) -> Self
Create a new StorageClient
Sourceimpl<T, Client> StorageClient<T, Client>where
T: Config,
Client: OfflineClientT<T>,
impl<T, Client> StorageClient<T, Client>where
T: Config,
Client: OfflineClientT<T>,
Sourcepub fn validate<Address: StorageAddress>(
&self,
address: &Address,
) -> Result<(), Error>
pub fn validate<Address: StorageAddress>( &self, address: &Address, ) -> Result<(), Error>
Run the validation logic against some storage address you’d like to access. Returns Ok(())
if the address is valid (or if it’s not possible to check since the address has no validation hash).
Return an error if the address was not valid or something went wrong trying to validate it (ie
the pallet or storage entry in question do not exist at all).
Sourcepub fn address_root_bytes<Address: StorageAddress>(
&self,
address: &Address,
) -> Vec<u8> ⓘ
pub fn address_root_bytes<Address: StorageAddress>( &self, address: &Address, ) -> Vec<u8> ⓘ
Convert some storage address into the raw bytes that would be submitted to the node in order to retrieve the entries at the root of the associated address.
Sourcepub fn address_bytes<Address: StorageAddress>(
&self,
address: &Address,
) -> Result<Vec<u8>, Error>
pub fn address_bytes<Address: StorageAddress>( &self, address: &Address, ) -> Result<Vec<u8>, Error>
Convert some storage address into the raw bytes that would be submitted to the node in order
to retrieve an entry. This fails if StorageAddress::append_entry_bytes does; in the built-in
implementation this would be if the pallet and storage entry being asked for is not available on the
node you’re communicating with, or if the metadata is missing some type information (which should not
happen).
Sourceimpl<T, Client> StorageClient<T, Client>where
T: Config,
Client: OnlineClientT<T>,
impl<T, Client> StorageClient<T, Client>where
T: Config,
Client: OnlineClientT<T>,